<?php
	/**
	* Slider Pro 
	*/
	
	if (!defined('ABSPATH')) {
		exit();
	}
	
	class Adsight_Slider_Admin
	{
		private $plugin = null;
	
		public function __construct()
		{
			$this->plugin = Adsight_Slider::get_instance();
			$options = get_option("adsight-slider");
			
			add_action('admin_init', array($this, 'register_settings'));
			add_action('admin_menu', array($this, 'add_settings_page'));
			add_action( 'plugin_action_links_' . $this->plugin::$plugin_basename,  array($this, 'settings_link'), 10 );
			
			/* Update Function */
			add_filter( 'plugins_api', array( $this, 'info' ), 20, 3 );
			add_filter( 'pre_set_site_transient_update_plugins', array( $this, 'update' ) );  
			add_action( 'upgrader_process_complete', array( $this, 'purge' ), 10, 2 );

			
			add_action ( 'admin_enqueue_scripts', function () {
				if (is_admin ())
						wp_enqueue_media ();
						add_thickbox();
						wp_enqueue_script('adslider-admin', plugins_url("adsight-slider/admin.js"),  array('thickbox'), $this->plugin::VERSION);
			});
		}
		
		function settings_link($links){
			$url = esc_url(add_query_arg(
				'page',
				$this->plugin::NAME,
				get_admin_url() . 'options-general.php'
			));
			
			array_unshift($links, "<a href='$url'>" . esc_html__('Settings', 'adsight-player') . '</a>');
			return $links;
		}
		
		public function add_settings_page()
		{
			add_options_page(
				__('Adsight Slider', "adsight-slider"),
				__('Adsight Slider', "adsight-slider"),
				'manage_options',
				"adsight-slider",
				array($this, 'render_settings_page')
			);
		}
		
		function register_settings(){
			load_plugin_textdomain( 'adsight-slider', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
			register_setting(
				"adsight-slider",
				"adsight-slider",
				array('sanitize_callback' => array($this, 'validate_options'))
			);
			
			add_settings_section('slider_general', __('General Options', "adsight-slider"), '', "adsight-slider");
			add_settings_field('slider_general_video_url', __('Video URL', "adsight-slider"), array($this, 'slider_general_video_url'), "adsight-slider", 'slider_general');
			add_settings_field('slider_general_loop', __('Play in loop', "adsight-slider"), array($this, 'slider_general_loop'), "adsight-slider", 'slider_general');
			add_settings_field('slider_placement_show_loggedin_users', __('Show ad logged in user', "adsight-slider"), array($this, 'slider_placement_show_loggedin_users'), "adsight-slider", 'slider_general');
			add_settings_field('slider_placement_header', __('Anchor Ad', "adsight-slider"), array($this, 'slider_placement_header'), "adsight-slider", 'slider_general');
			add_settings_field('slider_placement_paragraph', __('Paragraph', "adsight-slider"), array($this, 'slider_placement_paragraph'), "adsight-slider", 'slider_general');
			add_settings_field('slider_read_this', __('You read this text', "adsight-slider"), array($this, 'slider_read_this'), "adsight-slider", 'slider_general');		
		}
		
		function slider_general_video_url(){
			$options = get_option("adsight-slider");
			if(is_bool($options)){
				$video_url = array();	
			}else{
				$video_url = $this->plugin::$is_configured ? $options["video_url"] : array();		
			}
			$i = 1; 
			echo '<div id="videolist">';
			foreach($video_url as $url){
				echo '<div style="padding-bottom:5px"><input id="slider_general_video_url_'.$i.'" name="adsight-slider[video_url][]" type="text" value="' . esc_attr($url) . '" class="regular-text code"/><input type="hidden" id="slider_general_video_id_'.$i.'" rel="slider_general_video_url_'.$i.'" /><button class="set_custom_video button action">'.__('Select Local Video', "adsight-slider").'</button><button class="adsight-libary button action">Adsight Libary</button><button class="delete_custom_video button action">'.__('Delete', "adsight-slider").'</button></div>';
				$i++;
			}
			echo '</div>';
			echo '<button id="clone_video" data-next="'.$i.'" class="button action">'.__('Add new video', "adsight-slider").'</button>';
			echo '<div id="adsight-inline" style="display:none;"><div id="adsight-videos"></div>';
		}
		
		function slider_general_loop(){
			$options = get_option("adsight-slider");
			if(is_bool($options)){
				$loop =  "yes";	
			}else{
				$loop = $this->plugin::$is_configured ? esc_attr($options["loop"]) : "yes";	
			}
			$loop_no = '';
			if($loop != "yes"){
				$loop_no = 'selected="selected"';
			}
			echo '<select name="'."adsight-slider" . '[loop]" id="slider_general_loop">
			<option value="yes">'.__('Yes', "adsight-slider").'</option>
			<option value="no" '.$loop_no.'>'.__('No', "adsight-slider").'</option>
			</select>';
		}
		
		function slider_placement_show_loggedin_users(){
			$options = get_option("adsight-slider");
			if(is_bool($options)){
				$loggedin =  "yes";	
			}else{
				$loggedin = $this->plugin::$is_configured ? esc_attr($options["loggedin"]) : "yes";	
			}
			$loggedin_no = '';
			if($loggedin != "yes"){
				$loggedin_no = 'selected="selected"';
			}
			echo '<select name="'."adsight-slider" . '[loggedin]">
			<option value="yes">'.__('Yes', "adsight-slider").'</option>
			<option value="no" '.$loggedin_no.'>'.__('No', "adsight-slider").'</option>
			</select>';
		}
		
		function slider_placement_header(){
			$options = get_option("adsight-slider");
			if(is_bool($options)){
				$header =  "no";
			}else{
				$header = $this->plugin::$is_configured ? esc_attr($options["header-ads"]) : "no";	
			}
			$header_no = '';
			if($header != "yes"){
				$header_no = 'selected="selected"';
			}
			echo '<select name="'."adsight-slider" . '[header-ads]">
			<option value="yes">'.__('Yes', "adsight-slider").'</option>
			<option value="no" '.$header_no.'>'.__('No', "adsight-slider").'</option>
			</select>';
		}

		function slider_placement_paragraph(){
			$options = get_option("adsight-slider");
			if(is_bool($options)){
				$paragrah = 2;
			}else{
				$paragrah = $this->plugin::$is_configured ? esc_attr($options["paragrah"]) : 2;	
			}
			echo '<input type="text" name="'."adsight-slider" . '[paragrah]" value="'.$paragrah.'" type="value"/>';
		}

		function slider_read_this(){
			$options = get_option("adsight-slider");
			if(is_bool($options)){
				$read_this = 'Je leest nu: ';
			}else{
				$read_this = $this->plugin::$is_configured ? esc_attr($options["read_this"]) : '';	
			}
			echo '<input type="text" name="'."adsight-slider" . '[read_this]" value="'.$read_this.'" type="value"/>';
		}
	
			
		function render_settings_page(){
		?>
		<div class="wrap">
			<h1><?php esc_html_e('Adsight Slider', "adsight-slider"); ?></h1>
		
			<form method="post" action="options.php">
				<?php
				settings_fields("adsight-slider");
				do_settings_sections("adsight-slider");
				submit_button();
				?>
			</form>
		</div>
		<?php
		}

		function validate_options($settings){
			if(!in_array($settings['loop'],array('yes','no'))){
				add_settings_error("adsight-slider", 'loop', __('Invalid value for Play in loop', "adsight-slider"), 'error');
			}

			if(!in_array($settings['loggedin'], array('yes','no'))){
				add_settings_error("adsight-slider", 'loggedin', __('Invalid value for Show logged in user', "adsight-slider"), 'error');
			}
			foreach($settings['video_url'] as $key => $url){
				if(!preg_match('/^(http(s)?:\/\/|www\.).*(\.mp4|\.mov)$/', $url)){
					if(!preg_match('/^(http(s)?:\/\/|www\.).*$/', $url)){
						add_settings_error("adsight-slider", 'video_url', __('Video URL is not a valid url', "adsight-slider"), 'error');
					}else{
						if(!preg_match('/^*(\.mp4|\.mov)$/', $url)){
							add_settings_error("adsight-slider", 'video_url', __('Video file is not a valid video file', "adsight-slider"), 'error');
						}
					}
					unset($settings['video_url'][$key]);
				}	
			}
			
			
			return $settings;
		}
		
		public function request(){
		
			$remote = get_transient( $this -> plugin::$cache_key );
		
			//Enable force check via update-core.php
			if(isset($_GET['force-check']) && $_GET['force-check'] == 1){
				$remote = false;
			}
		
			if( false === $remote || ! $this -> plugin::$cache_allowed ) {
		
				$remote = wp_remote_get(
					'https://adsight.nl/downloads/adsight-slider.json',
					array(
						'timeout' => 10,
						'headers' => array(
							'Accept' => 'application/json'
						)
					)
				);
		
				if(
					is_wp_error( $remote )
					|| 200 !== wp_remote_retrieve_response_code( $remote )
					|| empty( wp_remote_retrieve_body( $remote ) )
				) {
					return false;
				}
		
				set_transient($this -> plugin::$cache_key, $remote, DAY_IN_SECONDS );
		
			}
		
			$remote = json_decode( wp_remote_retrieve_body( $remote ) );
		
			return $remote;
		
		}
		
		
		function info( $res, $action, $args ) {
		
			// do nothing if you're not getting plugin information right now
			if( 'plugin_information' !== $action ) {
				return $res;
			}
		
			// do nothing if it is not our plugin
			if( $this->plugin::$plugin_slug !== $args->slug ) {
				return $res;
			}
		
			// get updates
			$remote = $this->request();
		
			if( ! $remote ) {
				return $res;
			}
		
			$res = new stdClass();
		
			$res->name = $remote->name;
			$res->slug = $remote->slug;
			$res->version = $remote->version;
			$res->tested = $remote->tested;
			$res->requires = $remote->requires;
			$res->author = $remote->author;
			$res->author_profile = $remote->author_profile;
			$res->download_link = $remote->download_url;
			$res->trunk = $remote->download_url;
			$res->requires_php = $remote->requires_php;
			$res->last_updated = $remote->last_updated;
		
			$res->sections = array(
				'description' => $remote->sections->description,
				'installation' => $remote->sections->installation,
				'changelog' => $remote->sections->changelog
			);
		
			if( ! empty( $remote->banners ) ) {
				$res->banners = array(
					'low' => $remote->banners->low,
					'high' => $remote->banners->high
				);
			}
		
			return $res;
		
		}
		
		public function update( $transient ) {
		
			$remote = $this->request();
		
			if(
				$remote
				&& version_compare( $this->plugin::VERSION, $remote->version, '<' )
				&& version_compare( $remote->requires, get_bloginfo( 'version' ), '<=' )
				&& version_compare( $remote->requires_php, PHP_VERSION, '<' )
			) {
				//Update available
				
				$res = new stdClass();
				$res->slug = $this->plugin::$plugin_slug;
				$res->plugin = $this->plugin::$plugin_basename_file; 
				$res->new_version = $remote->version;
				$res->tested = $remote->tested;
				$res->package = $remote->download_url;
		
				$transient->response[ $res->plugin ] = $res;
		
					}else{
				//No update or no connection
				
				$res = new stdClass();
				$res->id = $this->plugin::$plugin_basename_file;
				$res->slug = $this->plugin::$plugin_slug;
				$res->plugin = $this->plugin::$plugin_basename_file;
				$res->new_version = $this->plugin::VERSION;
				$res->url = '';
				$res->package = '';
				$res->icons = [];
				$res->banners = [];
				$res->banners_rtl = [];
				$res->tested = '';
				$res->requires_php = '';
				$res->compatibility = new stdClass();
		
				$transient->no_update[$res->plugin] = $res;
				
			}
		
			return $transient;
		
		}
		
		public function purge( $upgrader, $options ){
		
			if (
				$this->cache_allowed
				&& 'update' === $options['action']
				&& 'plugin' === $options[ 'type' ]
			) {
				// just clean the cache when new plugin version is installed
				delete_transient( $this->cache_key );
			}
		
		}
		
	}
	
	